@@ -1,3 +1,8 @@
+
+#define	NUM_KEYCODES	150
+#define	GLYPHS_PER_KEY	4
+
+
 #include <X11/X.h>
 #include <X11/keysym.h>
 #include "xf86Keymap.h"
